==> sso-api-1.0.26-20170712.102042-3-sources.jar: cn/com/duiba/sso/api/web/logger/runnable/SsoLoggerRunnable.java <==
package cn.com.duiba.sso.api.web.logger.runnable;

import cn.com.duiba.sso.api.domain.dto.AdminDto;
import cn.com.duiba.sso.api.domain.enums.SystemEnum;
import cn.com.duiba.sso.api.remoteservice.RemoteManagerLogService;
import cn.com.duiba.sso.api.web.logger.domain.SsoLoggerParams;
import cn.com.duiba.sso.api.web.logger.domain.SsoLoggerTheadContext;
import cn.com.duiba.sso.api.web.tool.RequestParams;
import com.alibaba.fastjson.JSONObject;
import com.google.common.base.Objects;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * Created by liuyao on 2017/6/19.
 * 异步打印日志
 */
public class SsoLoggerRunnable implements Runnable {

    private Logger logger = LoggerFactory.getLogger(SsoLoggerRunnable.class);

    private SsoLoggerTheadContext context;

    private RequestParams requestParams;

    private RemoteManagerLogService remoteManagerLogService;

    private SystemEnum system;

    @Override
    public void run() {
        AdminDto admin = requestParams.getAdmin();
        Long adminId = 0L;
        String adminName = "免验请求";
        if(!Objects.equal(null,admin)){
            adminId = admin.getId();
            adminName = admin.getName();
        }

        List<JSONObject> paramsList = context.getParams();
        for(JSONObject log:paramsList){
            JSONObject model = new JSONObject();
            model.put("adminId",adminId);
            model.put("adminName",adminName);
            model.putAll(log);

            String logContext = replaceArgs(context.getTemplate(),model);
            SsoLoggerParams params = new SsoLoggerParams();
            params.setAdminId(adminId);
            params.setGroup(context.getGroup());
            params.setSystem(system);
            params.setIp(requestParams.getIp());
            params.setParamsJson(log);
            params.setLogContent(logContext);
            remoteManagerLogService.log(params);
        }
    }

    /**
     * 替换模板变量
     * @param template
     * @param data
     * @return
     */
    private String replaceArgs(final String template, JSONObject data){
        // sb用来存储替换过的内容，它会把多次处理过的字符串按源字符串序 存储起来。
        StringBuffer sb = new StringBuffer();
        try{
            Pattern pattern = Pattern.compile("\\$\\{(.+?)\\}");
            Matcher matcher = pattern.matcher(template);
            while(matcher.find()){
                String name = matcher.group(1);// 键名
                String value = "";// 键值
                if(data.containsKey(name)){
                    value = data.getString(name);// 键值
                    value = value.replaceAll("\\$", "\\\\\\$");
                }
                matcher.appendReplacement(sb, value);
            }
            matcher.appendTail(sb);
        }catch(Exception e){
            logger.error("管理员操作日志渲染失败",e);
        }
        System.out.println("日志:"+sb.toString());
        return sb.toString();
    }

    public SsoLoggerTheadContext getContext() {
        return context;
    }

    public void setContext(SsoLoggerTheadContext context) {
        this.context = context;
    }

    public RequestParams getRequestParams() {
        return requestParams;
    }

    public void setRequestParams(RequestParams requestParams) {
        this.requestParams = requestParams;
    }

    public void setRemoteManagerLogService(RemoteManagerLogService remoteManagerLogService) {
        this.remoteManagerLogService = remoteManagerLogService;
    }

    public SystemEnum getSystem() {
        return system;
    }

    public void setSystem(SystemEnum system) {
        this.system = system;
    }
}

==> sso-api-1.2.0-20180112.093425-4-sources.jar: cn/com/duiba/sso/api/web/logger/runnable/SsoLoggerRunnable.java <==
package cn.com.duiba.sso.api.web.logger.runnable;

import cn.com.duiba.sso.api.domain.dto.AdminDto;
import cn.com.duiba.sso.api.remoteservice.RemoteManagerLogService;
import cn.com.duiba.sso.api.web.logger.domain.SsoLoggerParams;
import cn.com.duiba.sso.api.web.logger.domain.SsoLoggerTheadContext;
import cn.com.duiba.sso.api.tool.RequestParams;
import cn.com.duiba.sso.api.tool.SystemInfo;
import com.alibaba.fastjson.JSONObject;
import com.google.common.base.Objects;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * Created by liuyao on 2017/6/19.
 * 异步打印日志
 */
public class SsoLoggerRunnable implements Runnable {

    private Logger logger = LoggerFactory.getLogger(SsoLoggerRunnable.class);

    private SsoLoggerTheadContext context;

    private RequestParams requestParams;

    private RemoteManagerLogService remoteManagerLogService;

    @Override
    public void run() {
        AdminDto admin = requestParams.getAdmin();
        Long adminId = 0L;
        String adminName = "免验请求";
        if(!Objects.equal(null,admin)){
            adminId = admin.getId();
            adminName = admin.getName();
        }

        List<JSONObject> paramsList = context.getParams();
        for(JSONObject log:paramsList){
            JSONObject model = new JSONObject();
            model.put("adminId",adminId);
            model.put("adminName",adminName);
            model.putAll(log);

            String logContext = replaceArgs(context.getTemplate(),model);
            SsoLoggerParams params = new SsoLoggerParams();
            params.setAdminId(adminId);
            params.setGroup(context.getGroup());
            params.setSystemId(SystemInfo.getThisSystemId());
            params.setIp(requestParams.getIp());
            params.setParamsJson(log);
            params.setLogContent(logContext);
            remoteManagerLogService.log(params);
        }
    }

    /**
     * 替换模板变量
     * @param template
     * @param data
     * @return
     */
    private String replaceArgs(final String template, JSONObject data){
        // sb用来存储替换过的内容，它会把多次处理过的字符串按源字符串序 存储起来。
        StringBuffer sb = new StringBuffer();
        try{
            Pattern pattern = Pattern.compile("\\$\\{(.+?)\\}");
            Matcher matcher = pattern.matcher(template);
            while(matcher.find()){
                String name = matcher.group(1);// 键名
                String value = "";// 键值
                if(data.containsKey(name)){
                    value = data.getString(name);// 键值
                    value = value.replaceAll("\\$", "\\\\\\$");
                }
                matcher.appendReplacement(sb, value);
            }
            matcher.appendTail(sb);
        }catch(Exception e){
            logger.error("管理员操作日志渲染失败",e);
        }
        return sb.toString();
    }

    public SsoLoggerTheadContext getContext() {
        return context;
    }

    public void setContext(SsoLoggerTheadContext context) {
        this.context = context;
    }

    public RequestParams getRequestParams() {
        return requestParams;
    }

    public void setRequestParams(RequestParams requestParams) {
        this.requestParams = requestParams;
    }

    public void setRemoteManagerLogService(RemoteManagerLogService remoteManagerLogService) {
        this.remoteManagerLogService = remoteManagerLogService;
    }
}
